/*===================================================================

The Medical Imaging Interaction Toolkit (MITK)

Copyright (c) German Cancer Research Center,
Division of Medical and Biological Informatics.
All rights reserved.

This software is distributed WITHOUT ANY WARRANTY; without
even the implied warranty of MERCHANTABILITY or FITNESS FOR
A PARTICULAR PURPOSE.

See LICENSE.txt or http://www.mitk.org for details.

===================================================================*/


#ifndef MITKSEEDSIMAGELOOKUPTABLESOURCE_H_HEADER_INCLUDED
#define MITKSEEDSIMAGELOOKUPTABLESOURCE_H_HEADER_INCLUDED

#include "mitkCommon.h"
#include "MitkExtExports.h"
#include "mitkLookupTableSource.h"


namespace mitk
{

class MitkExt_EXPORT SeedsImageLookupTableSource : public LookupTableSource
{
public:
  typedef enum {Seeds, DefaultLUT, Force} LookupTableMode;

  mitkClassMacro( SeedsImageLookupTableSource, LookupTableSource );
  itkNewMacro( Self );

  /** @brief Some convenient typedefs. */
  typedef mitk::LookupTable OutputType;

  void SetUseSeedsLookupTable() {m_Mode = Seeds; this->Modified();};

  void SetUseForceLookupTable() {m_Mode = Force; this->Modified();};

protected:
  SeedsImageLookupTableSource();
  virtual ~SeedsImageLookupTableSource();

    /**
    * Generates a LookupTable depended on the given mode and stores
    * it in an output object
    */
  virtual void GenerateData();

  /**
    * Generates a lookup table, dependend on the given mode
    * @returns a vtkLookupTable
    */
  vtkLookupTable* BuildVtkLookupTable( );

  /**
    * Generates a Seeds lookup table
    * @returns a vtkLookupTable
    */
  vtkLookupTable* BuildSeedsLookupTable();

  /**
    * Generates a force lookup table
    * @returns a vtkLookupTable
    */
  vtkLookupTable* BuildForceLookupTable();

  /**
    * Generates a default lookup table
    * @returns a vtkLookupTable
    */
  vtkLookupTable* BuildDefaultLookupTable();

private:
  LookupTableMode m_Mode;
  OutputTypePointer m_LookupTable;
};

} // namespace mitk

#endif /* MITKSEEDSIMAGELOOKUPSOURCE_H_HEADER_INCLUDED */
