/*===================================================================

The Medical Imaging Interaction Toolkit (MITK)

Copyright (c) German Cancer Research Center,
Division of Medical and Biological Informatics.
All rights reserved.

This software is distributed WITHOUT ANY WARRANTY; without
even the implied warranty of MERCHANTABILITY or FITNESS FOR
A PARTICULAR PURPOSE.

See LICENSE.txt or http://www.mitk.org for details.

===================================================================*/


#ifndef MITKSURFACEINTERACTOR_H_HEADER_INCLUDED
#define MITKSURFACEINTERACTOR_H_HEADER_INCLUDED

#include "mitkAffineInteractor.h"
#include "MitkExtExports.h"
#include "mitkPointLocator.h"

namespace mitk {

  //##Documentation
  //## @brief Interactor for Affine transformations on one or multiple surfaces
  //##
  //## A surface interacted by this class can translate, rotate and scale
  //## by modifying its geometry. The surface closest to the picking point is
  //## chosen for interaction automatically by CanHandleEvent
  //## @ingroup Interaction
  class MitkExt_EXPORT SurfaceInteractor : public AffineInteractor
  {
  public:
    mitkClassMacro(SurfaceInteractor,AffineInteractor);
    //  itkNewMacro(Self);
    mitkNewMacro2Param(Self, const char*, DataNode*);

  protected:

    //##Documentation
    //## @brief Constructor
    //##
    //## @param dataNode is the node, this Interactor is connected to
    //## @param type is the type of StateMachine like declared in the XML-Configure-File
    SurfaceInteractor(const char * type, DataNode* dataNode);

    //##Documentation
    //## @brief Destructor
    ~SurfaceInteractor(){};

    //##Documentation
    //## @brief calculates how good the data this state machine handles is hit by the event.
    //##
    //## Returns a value between 0 and 1.
    //## (Used by GlobalInteraction to decide which DESELECTED state machine to send the event to.)
    //##
    //## \WARNING This is interactor currently does not work for interaction in 3D. Try using mitkAffineInteractor3D instead.
    virtual float CanHandleEvent(StateEvent const* stateEvent) const;

  private:

    typedef PointLocator      PLocType;
    typedef PLocType::Pointer PLPointer;

    PLPointer                  m_PtLoc;

  };

} // namespace mitk

#endif /* MITKSURFACEINTERACTOR_H_HEADER_INCLUDED */
